@@ -73,6 +73,10 @@
 	#include <sys/types.h>
 	#include <sys/utsname.h>
 	#include <sys/wait.h>
+	#if defined(__ANDROID__) && \
+		(!defined(__USE_FILE_OFFSET64) || __ANDROID_API__ < 24)
+		#define fseeko fseek
+	#endif
 #endif /* _WIN32 */
 
 /*
@@ -626,7 +630,7 @@ int http_SendMessage(SOCKINFO *info, int *TimeOut, const char *fmt, ...)
 					rc = snprintf(Chunk_Header,
 						sizeof(Chunk_Header),
 						"%" PRIzx "\r\n",
-						(unsigned long)num_read);
+						num_read);
 					if (rc < 0 ||
 						(unsigned int)rc >=
 							sizeof(Chunk_Header)) {
@@ -1730,9 +1734,24 @@ int http_MakeMessage(membuffer *buf,
 				goto error_handler;
 		} else if (c == 'K') {
 			/* Add Chunky header */
-			if (membuffer_append(buf,
-				    "TRANSFER-ENCODING: chunked\r\n",
-				    strlen("Transfer-Encoding: chunked\r\n")))
+			if (membuffer_append_str(
+				    buf, "TRANSFER-ENCODING: chunked\r\n"))
+				goto error_handler;
+		} else if (c == 'A') {
+			/* Add Access-Control-Allow-Origin header only if
+			 * set by UpnpSetWebServerCorsString */
+			struct SendInstruction *RespInstr;
+			RespInstr = (struct SendInstruction *)va_arg(
+				argp, struct SendInstruction *);
+			assert(RespInstr);
+			if (RespInstr->CorsHeader &&
+				strcmp(RespInstr->CorsHeader, "") &&
+				http_MakeMessage(buf,
+					http_major_version,
+					http_minor_version,
+					"ssc",
+					"Access-Control-Allow-Origin: ",
+					RespInstr->CorsHeader) != 0)
 				goto error_handler;
 		} else if (c == 'G') {
 			/* Add Range header */
@@ -1765,10 +1784,7 @@ int http_MakeMessage(membuffer *buf,
 		} else if (c == 'd') {
 			/* integer */
 			num = (size_t)va_arg(argp, int);
-			rc = snprintf(tempbuf,
-				sizeof(tempbuf),
-				"%" PRIzu,
-				(unsigned long)num);
+			rc = snprintf(tempbuf, sizeof(tempbuf), "%" PRIzu, num);
 			if (rc < 0 || (unsigned int)rc >= sizeof(tempbuf) ||
 				membuffer_append(buf, tempbuf, strlen(tempbuf)))
 				goto error_handler;
